@@ -1,6 +1,6 @@
 <?php
 
-# FitGallery 0.95
+# FitGallery 1.00
 # (C) Copyright  Omar Lpez 'pollo', Enrique D. Bosch 'presi'
 # http://fitgallery.presi.org
 #
@@ -47,8 +47,6 @@ $dirimgs="imgs";
 $titulo_texto=strtr(strip_tags(file_get_contents($titulo)),"\n",'');
 $n=0;
 $total=0;
-$subtotal=0;
-$numimgs=0;
 
 $handle=opendir($dirgal);         # Scan galeries directory
 while (($file = readdir($handle))!==false)
@@ -65,9 +63,7 @@ while (($file = readdir($handle))!==false)
          $arr[$n]['mtime']=date($date_string,$mtime);
          $arr[$n]['file']=$file;
          $arr[$n]['subtotal']=$subtotal;
-         $subtotal=0;
          $arr[$n]['numimgs']=$numimgs;
-         $numimgs=0;
          $arr[$n]['primero']=$primero;
        }
       else
@@ -88,6 +84,8 @@ while (($file = readdir($handle))!==false)
            {
              $arr[$n]['primero']=$thumb_remoto;
              $arr[$n]['titulo']=$arrfich[3];
+             $arr[$n]['numimgs']='';
+             $arr[$n]['subtotal']='';
            }
        }
       $total += $arr[$n]['subtotal'];
@@ -97,7 +95,9 @@ while (($file = readdir($handle))!==false)
 }
 closedir($handle); 
 
-sort($arr);
+function compmtime($a,$b) { return $a['mtime'] > $b['mtime']; }
+usort($arr,'compmtime');
+
 $numero_arch=count($arr);
 
 if ($para>$numero_arch) exit_error('Images not found.');
@@ -158,7 +158,7 @@ for ( $i=$para ; $i <= $para2 ; $i++)
 
      html_image($arr[$i]['url_prefix'],$valor,$arr[$i]['primero'],$i,
                 $titulo_galeria_texto,$arr[$i]['numimgs'],$text_images,
-                $arr[$i]['subtotal'],$megas,$arr[$i]['mtime'],$remote_espace);
+                $arr[$i]['subtotal'],$megas,$arr[$i]['mtime'],$remote_espace,$h_thumb);
    }
 
 html_sep();
@@ -236,13 +236,15 @@ echo '</p>';
 
 
 function html_image($url_prefix,$valor,$portada,$i,$titulo_galeria_texto,
-                    $size,$text_images,$bytes,$megas,$fecha,$remote_espace)
+                    $size,$text_images,$bytes,$megas,$fecha,$remote_espace,$h_thumb)
 {
    echo "
    <div class=\"figure\">
    <p class=\"caption\">
    <a href=\"".$url_prefix."ver_thumb.php?galeria=$valor\">
+   <span style=\"border: none; display: block; height: ${h_thumb}px;\">
    <img class=\"thumbnail\" src=\"".$url_prefix."thumb.php?galeria=$valor&amp;valor=$portada&amp;tipo=t\" alt=\"$valor\">
+   </span>
    </a>
    </p>
    <p class=\"caption\">\n   ";
@@ -252,12 +254,14 @@ function html_image($url_prefix,$valor,$portada,$i,$titulo_galeria_texto,
    $valor<br>
    </a>
    $titulo_galeria_texto   <br>";
-   if ($size != '')
+   if ($size !== '')
     {
       echo "
-      $size $text_images<br>
+      $size $text_images<br>";
+      if ($bytes !== '') echo "
       $bytes bytes ($megas MB)<br>
-      $fecha";
+";
+      echo "      $fecha";
     }
    else if ($remote_espace) echo '<br><br><br>';
    echo '
