@@ -1,6 +1,6 @@
 <?php
 
-# FitGallery 0.95
+# FitGallery 1.00
 # (C) Copyright  Omar Lpez 'pollo', Enrique D. Bosch 'presi'
 # http://fitgallery.presi.org
 #
@@ -27,6 +27,8 @@ $mtime=filemtime("$dirgal/$file");
 $handledir=opendir("$dirgal/$file/$dirimgs");
 $primero=NULL;
 $fecha_primero=PHP_INT_MAX;
+$numimgs=0;
+$subtotal=0;
 while (($fileimgs = readdir($handledir))!==false)
   {
     if ($fileimgs != '.' && $fileimgs != '..')
